@@ -1,12 +1,12 @@
 ###########################################################################
-# $Id: schema.sql,v 1.8 2008/03/14 08:29:50 aland Exp $                 #
+# $Id$                 #
 #                                                                         #
-#  db_mysql.sql                     rlm_sql - FreeRADIUS SQL Module       #
+#  schema.sql                       rlm_sql - FreeRADIUS SQL Module       #
 #                                                                         #
 #     Database schema for MySQL rlm_sql module                            #
 #                                                                         #
 #     To load:                                                            #
-#         mysql -uroot -prootpass radius < db_mysql.sql                   #
+#         mysql -uroot -prootpass radius < schema.sql                     #
 #                                                                         #
 #                                   Mike Machado <mike@innercite.com>     #
 ###########################################################################
