@@ -1,7 +1,7 @@
 /*
  * radclient.c	General radius packet debug tool.
  *
- * Version:	$Id: radclient.c,v 1.119 2008/03/08 17:23:47 aland Exp $
+ * Version:	$Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  */
 
 #include <freeradius-devel/ident.h>
-RCSID("$Id: radclient.c,v 1.119 2008/03/08 17:23:47 aland Exp $")
+RCSID("$Id$")
 
 #include <freeradius-devel/libradius.h>
 #include <freeradius-devel/conf.h>
@@ -184,7 +184,7 @@ static radclient_t *radclient_init(const char *filename)
 
 		radclient->request = rad_alloc(1);
 		if (!radclient->request) {
-			librad_perror("radclient: Y");
+			fr_perror("radclient: Y");
 			radclient_free(radclient);
 			if (fp != stdin) fclose(fp);
 			return NULL; /* memory leak "start" */
@@ -526,7 +526,7 @@ static int send_one_packet(radclient_t *radclient)
 		assert(radclient->request->data == NULL);
 
 		for (i = 0; i < 4; i++) {
-			*((uint32_t *) radclient->request->vector) = fr_rand();
+			((uint32_t *) radclient->request->vector)[i] = fr_rand();
 		}
 
 		/*
@@ -634,10 +634,10 @@ static int send_one_packet(radclient_t *radclient)
 	 */
 	if (rad_send(radclient->request, NULL, secret) < 0) {
 		fprintf(stderr, "radclient: Failed to send packet for ID %d: %s\n",
-			radclient->request->id, librad_errstr);
+			radclient->request->id, fr_strerror());
 	}
 
-	if (librad_debug > 2) print_hex(radclient->request);
+	if (fr_debug_flag > 2) print_hex(radclient->request);
 
 	return 0;
 }
@@ -679,7 +679,7 @@ static int recv_one_packet(int wait_time)
 	reply = fr_packet_list_recv(pl, &set);
 	if (!reply) {
 		fprintf(stderr, "radclient: received bad packet: %s\n",
-			librad_errstr);
+			fr_strerror());
 		return -1;	/* bad packet */
 	}
 
@@ -690,7 +690,7 @@ static int recv_one_packet(int wait_time)
 	 */
 	reply->dst_ipaddr = client_ipaddr;
 
-	if (librad_debug > 2) print_hex(reply);
+	if (fr_debug_flag > 2) print_hex(reply);
 
 	request_p = fr_packet_list_find_byreply(pl, reply);
 	if (!request_p) {
@@ -705,7 +705,7 @@ static int recv_one_packet(int wait_time)
 	 *	FIXME: Silently drop it and listen for another packet.
 	 */
 	if (rad_verify(reply, radclient->request, secret) < 0) {
-		librad_perror("rad_verify");
+		fr_perror("rad_verify");
 		totallost++;
 		goto packet_done; /* shared secret is incorrect */
 	}
@@ -722,13 +722,13 @@ static int recv_one_packet(int wait_time)
 	 *	If this fails, we're out of memory.
 	 */
 	if (rad_decode(reply, radclient->request, secret) != 0) {
-		librad_perror("rad_decode");
+		fr_perror("rad_decode");
 		totallost++;
 		goto packet_done;
 	}
 
 	/* libradius debug already prints out the value pairs for us */
-	if (!librad_debug && do_output) {
+	if (!fr_debug_flag && do_output) {
 		printf("Received response ID %d, code %d, length = %d\n",
 		       reply->id, reply->code, reply->data_len);
 		vp_printlist(stdout, reply->vps);
@@ -775,7 +775,7 @@ int main(int argc, char **argv)
 	radclient_t	*this;
 	int force_af = AF_UNSPEC;
 
-	librad_debug = 0;
+	fr_debug_flag = 0;
 
 	filename_tree = rbtree_create(filename_cmp, NULL, 0);
 	if (!filename_tree) {
@@ -832,6 +832,7 @@ int main(int argc, char **argv)
 
 		case 'q':
 			do_output = 0;
+			fr_log_fp = NULL; /* no output from you, either! */
 			break;
 		case 'r':
 			if (!isdigit((int) *optarg))
@@ -876,11 +877,11 @@ int main(int argc, char **argv)
 			timeout = atof(optarg);
 			break;
 		case 'v':
-			printf("radclient: $Id: radclient.c,v 1.119 2008/03/08 17:23:47 aland Exp $ built on " __DATE__ " at " __TIME__ "\n");
+			printf("radclient: $Id$ built on " __DATE__ " at " __TIME__ "\n");
 			exit(0);
 			break;
 		case 'x':
-			librad_debug++;
+			fr_debug_flag++;
 			fr_log_fp = stdout;
 			break;
 		case 'h':
@@ -897,7 +898,7 @@ int main(int argc, char **argv)
 	}
 
 	if (dict_init(radius_dir, RADIUS_DICTIONARY) < 0) {
-		librad_perror("radclient");
+		fr_perror("radclient");
 		return 1;
 	}
 
@@ -1026,7 +1027,7 @@ int main(int argc, char **argv)
 	}
 	sockfd = fr_socket(&client_ipaddr, client_port);
 	if (sockfd < 0) {
-		fprintf(stderr, "radclient: socket: %s\n", librad_errstr);
+		fprintf(stderr, "radclient: socket: %s\n", fr_strerror());
 		exit(1);
 	}
 
